summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/EntropyContext.cpp
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/EntropyContext.cpp (renamed from src/PolarSSL++/EntropyContext.cpp)8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/PolarSSL++/EntropyContext.cpp b/src/mbedTLS++/EntropyContext.cpp
index 9c59b3f11..aea056f4e 100644
--- a/src/PolarSSL++/EntropyContext.cpp
+++ b/src/mbedTLS++/EntropyContext.cpp
@@ -1,7 +1,7 @@
-
+
// EntropyContext.cpp
// Implements the cEntropyContext class representing a wrapper over entropy contexts in PolarSSL
#include "Globals.h"
#include "EntropyContext.h"
@@ -12,7 +12,7 @@
cEntropyContext::cEntropyContext(void)
{
- entropy_init(&m_Entropy);
+ mbedtls_entropy_init(&m_Entropy);
}
@@ -21,7 +21,7 @@ cEntropyContext::cEntropyContext(void)
cEntropyContext::~cEntropyContext()
{
- entropy_free(&m_Entropy);
+ mbedtls_entropy_free(&m_Entropy);
}
@@ -1,7 +1,7 @@
// EntropyContext.cpp
-// Implements the cEntropyContext class representing a wrapper over entropy contexts in PolarSSL
+// Implements the cEntropyContext class representing a wrapper over entropy contexts in mbedTLS
#include "Globals.h"
#include "EntropyContext.h"